Reference
=========

The following pages give detailed descriptions of the API exposed by penguins.
It is currently incomplete, but will be updated in the near future.

.. toctree::
   :maxdepth: 2

   reading
   dataset
   plotting
